@@ -2,14 +2,13 @@ package main
 
 import (
 	"fmt"
-	"github.com/snowflakedb/gosnowflake"
 	"net/url"
 	"regexp"
 	"strconv"
 	"strings"
 	"time"
 
-	_ "github.com/ClickHouse/clickhouse-go" // register the ClickHouse driver
+	_ "github.com/ClickHouse/clickhouse-go/v2" // register the ClickHouse driver
 	"github.com/cenkalti/backoff"
 	_ "github.com/denisenkom/go-mssqldb" // register the MS-SQL driver
 	"github.com/go-kit/log"
@@ -18,7 +17,8 @@ import (
 	"github.com/jmoiron/sqlx"
 	_ "github.com/lib/pq" // register the PostgreSQL driver
 	"github.com/prometheus/client_golang/prometheus"
-	_ "github.com/segmentio/go-athena"     // register the AWS Athena driver
+	_ "github.com/segmentio/go-athena" // register the AWS Athena driver
+	"github.com/snowflakedb/gosnowflake"
 	_ "github.com/vertica/vertica-sql-go" // register the Vertica driver
 )
 
@@ -70,14 +70,11 @@ func (j *Job) Init(logger log.Logger, queries map[string]string) error {
 			},
 		)
 	}
+	j.updateConnections()
 	return nil
 }
 
-// Run prepares and runs the job
-func (j *Job) Run() {
-	if j.log == nil {
-		j.log = log.NewNopLogger()
-	}
+func (j *Job) updateConnections() {
 	// if there are no connection URLs for this job it can't be run
 	if j.Connections == nil {
 		level.Error(j.log).Log("msg", "No connections for job", "job", j.Name)
@@ -171,16 +168,12 @@ func (j *Job) Run() {
 			j.conns = append(j.conns, newConn)
 		}
 	}
-	level.Debug(j.log).Log("msg", "Starting")
+}
 
-	// enter the run loop
-	// tries to run each query on each connection at approx the interval
+func (j *Job) ExecutePeriodically() {
+	level.Debug(j.log).Log("msg", "Starting")
 	for {
-		bo := backoff.NewExponentialBackOff()
-		bo.MaxElapsedTime = j.Interval
-		if err := backoff.Retry(j.runOnce, bo); err != nil {
-			level.Error(j.log).Log("msg", "Failed to run", "err", err)
-		}
+		j.Run()
 		level.Debug(j.log).Log("msg", "Sleeping until next run", "sleep", j.Interval.String())
 		time.Sleep(j.Interval)
 	}
@@ -225,6 +218,18 @@ func (j *Job) markFailed(conn *connection) {
 	}
 }
 
+// Run the job queries with exponential backoff, implements the cron.Job interface
+func (j *Job) Run() {
+	bo := backoff.NewExponentialBackOff()
+	bo.MaxElapsedTime = j.Interval
+	if bo.MaxElapsedTime == 0 {
+		bo.MaxElapsedTime = time.Minute
+	}
+	if err := backoff.Retry(j.runOnce, bo); err != nil {
+		level.Error(j.log).Log("msg", "Failed to run", "err", err)
+	}
+}
+
 func (j *Job) runOnce() error {
 	doneChan := make(chan int, len(j.conns))
 
